==> huaweicloudsdkdws-3.1.131-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/workload_queue_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class WorkloadQueueRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workload_queue': 'WorkloadQueueInfo'
    }

    attribute_map = {
        'workload_queue': 'workload_queue'
    }

    def __init__(self, workload_queue=None):
        """WorkloadQueueRequest

        The model defined in huaweicloud sdk

        :param workload_queue: 
        :type workload_queue: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        
        

        self._workload_queue = None
        self.discriminator = None

        self.workload_queue = workload_queue

    @property
    def workload_queue(self):
        """Gets the workload_queue of this WorkloadQueueRequest.

        :return: The workload_queue of this WorkloadQueueRequest.
        :rtype: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        return self._workload_queue

    @workload_queue.setter
    def workload_queue(self, workload_queue):
        """Sets the workload_queue of this WorkloadQueueRequest.

        :param workload_queue: The workload_queue of this WorkloadQueueRequest.
        :type workload_queue: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        self._workload_queue = workload_queue

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkloadQueueRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdws-3.1.148-py2.py3-none-any.whl: huaweicloudsdkdws/v2/model/workload_queue_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class WorkloadQueueRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'workload_queue': 'WorkloadQueueInfo'
    }

    attribute_map = {
        'workload_queue': 'workload_queue'
    }

    def __init__(self, workload_queue=None):
        r"""WorkloadQueueRequest

        The model defined in huaweicloud sdk

        :param workload_queue: 
        :type workload_queue: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        
        

        self._workload_queue = None
        self.discriminator = None

        self.workload_queue = workload_queue

    @property
    def workload_queue(self):
        r"""Gets the workload_queue of this WorkloadQueueRequest.

        :return: The workload_queue of this WorkloadQueueRequest.
        :rtype: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        return self._workload_queue

    @workload_queue.setter
    def workload_queue(self, workload_queue):
        r"""Sets the workload_queue of this WorkloadQueueRequest.

        :param workload_queue: The workload_queue of this WorkloadQueueRequest.
        :type workload_queue: :class:`huaweicloudsdkdws.v2.WorkloadQueueInfo`
        """
        self._workload_queue = workload_queue

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkloadQueueRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
